@@ -17,18 +17,31 @@ class TikTokApi:
         if debug:
             print("Class initialized")
 
-        self.referrer = "https://www.tiktok.com/tag/jakefromstate?lang=en"
+        self.referrer = "https://www.tiktok.com/trending?lang="
+        #self.referrer = "https://www.tiktok.com/@ondymikula/video/6757762109670477061"
 
     #
     # Method that retrives data from the api
     #
-    def getData(self, api_url, signature, userAgent):
+    def getData(self, api_url, signature, userAgent, language='en'):
         url = api_url + \
             "&_signature=" + signature
         r = requests.get(url, headers={"method": "GET",
                                        "accept-encoding": "gzip, deflate, br",
-                                       "referrer": self.referrer,
+                                       "referrer": self.referrer + language,
                                        "user-agent": userAgent,
+                                       'accept': 'application/json, text/plain, */*',
+                                       'dnt': '1',
+                                       'cache-control': 'no-cache',
+                                       'scheme': 'https',
+                                       'authority': 'm.tiktok.com',
+                                       'origin': 'https://www.tiktok.com',
+                                       'pragma': 'no-cache',
+                                       'sec-fetch-dest': 'empty',
+                                       'sec-fetch-mode': 'cors',
+                                       'sec-fetch-site': 'same-site',
+                                       'path': url.split("tiktok.com")[1],
+                                       'accept-language': 'en-US,en;q=0.9'
                                        })
         try:
             return r.json()
@@ -56,7 +69,7 @@ class TikTokApi:
     # Gets trending Tiktoks
     #
 
-    def trending(self, count=30):
+    def trending(self, count=30, language='en'):
         response = []
         maxCount = 99
         maxCursor = 0
@@ -66,11 +79,10 @@ class TikTokApi:
                 realCount = count
             else:
                 realCount = maxCount
-
-            api_url = "https://m.tiktok.com/api/item_list/?count={}&id=1&type=5&secUid=&maxCursor={}&minCursor=0&sourceType=12&appId=1233&verifyFp=".format(
-            str(realCount), str(maxCursor))
-            b = browser(api_url)
-            res = self.getData(api_url, b.signature, b.userAgent)
+            api_url = "https://m.tiktok.com/api/item_list/?count={}&id=1&type=5&secUid=&maxCursor={}&minCursor=0&sourceType=12&appId=1233&region=US&language={}&verifyFp=".format(
+            str(realCount), str(maxCursor), str(language))
+            b = browser(api_url, language=language)
+            res = self.getData(api_url, b.signature, b.userAgent, language=language)
 
             for t in res['items']:
                 response.append(t)
@@ -88,7 +100,7 @@ class TikTokApi:
     #
     # Gets a specific user's tiktoks
     #
-    def userPosts(self, userID, secUID, count=30):
+    def userPosts(self, userID, secUID, count=30, language='en'):
         response = []
         maxCount = 99
         maxCursor = 0
@@ -99,8 +111,8 @@ class TikTokApi:
             else:
                 realCount = maxCount
 
-            api_url = "https://m.tiktok.com/api/item_list/?count={}&id={}&type=1&secUid={}&maxCursor={}&minCursor=0&sourceType=8&appId=1233&region=US&language=en&verifyFp=".format(
-            str(realCount), str(userID), str(secUID), str(maxCursor))
+            api_url = "https://m.tiktok.com/api/item_list/?count={}&id={}&type=1&secUid={}&maxCursor={}&minCursor=0&sourceType=8&appId=1233&region=US&language={}&verifyFp=".format(
+            str(realCount), str(userID), str(secUID), str(maxCursor), str(language))
             b = browser(api_url)
             res = self.getData(api_url, b.signature, b.userAgent)
 
@@ -131,7 +143,7 @@ class TikTokApi:
     # id - the sound ID
     #
 
-    def bySound(self, id, count=30):
+    def bySound(self, id, count=30, language='en'):
         response = []
         maxCount = 99
         maxCursor = 0
@@ -142,8 +154,8 @@ class TikTokApi:
             else:
                 realCount = maxCount
 
-            api_url = "https://m.tiktok.com/share/item/list?secUid=&id={}&type=4&count={}&minCursor=0&maxCursor={}&shareUid=&lang=en&verifyFp=".format(
-            str(id), str(realCount), str(maxCursor))
+            api_url = "https://m.tiktok.com/share/item/list?secUid=&id={}&type=4&count={}&minCursor=0&maxCursor={}&shareUid=&lang={}&verifyFp=".format(
+            str(id), str(realCount), str(maxCursor), str(language))
             b = browser(api_url)
             res = self.getData(api_url, b.signature, b.userAgent)
 
@@ -162,9 +174,9 @@ class TikTokApi:
     #
     # Gets the music object
     #
-    def getMusicObject(self, id):
-        api_url = "https://m.tiktok.com/api/music/detail/?musicId={}&language=en&verifyFp=".format(
-            str(id))
+    def getMusicObject(self, id, language='en'):
+        api_url = "https://m.tiktok.com/api/music/detail/?musicId={}&language={}&verifyFp=".format(
+            str(id), language)
         b = browser(api_url)
         return self.getData(api_url, b.signature, b.userAgent)
 
@@ -172,7 +184,7 @@ class TikTokApi:
     # Gets tiktoks by hashtag
     #
 
-    def byHashtag(self, hashtag, count=30):
+    def byHashtag(self, hashtag, count=30, language='en'):
         id = self.getHashtagObject(hashtag)['challengeInfo']['challenge']['id']
         response = []
         maxCount = 99
@@ -184,8 +196,8 @@ class TikTokApi:
             else:
                 realCount = maxCount
 
-            api_url = "https://m.tiktok.com/share/item/list?secUid=&id={}&type=3&count={}&minCursor=0&maxCursor={}&shareUid=&lang=en&verifyFp=".format(
-                str(id), str(realCount), str(maxCursor))
+            api_url = "https://m.tiktok.com/share/item/list?secUid=&id={}&type=3&count={}&minCursor=0&maxCursor={}&shareUid=&lang={}&verifyFp=".format(
+                str(id), str(realCount), str(maxCursor), language)
             b = browser(api_url)
             res = self.getData(api_url, b.signature, b.userAgent)
 
@@ -205,9 +217,9 @@ class TikTokApi:
     # Gets tiktoks by hashtag (for use in byHashtag)
     #
 
-    def getHashtagObject(self, hashtag):
-        api_url = "https://m.tiktok.com/api/challenge/detail/?verifyFP=&challengeName={}&language=en".format(
-            str(hashtag))
+    def getHashtagObject(self, hashtag, language='en'):
+        api_url = "https://m.tiktok.com/api/challenge/detail/?verifyFP=&challengeName={}&language={}".format(
+            str(hashtag), language)
         b = browser(api_url)
         return self.getData(api_url, b.signature, b.userAgent)
 
@@ -232,9 +244,9 @@ class TikTokApi:
     # Gets a user object for id and secUid
     #
 
-    def getUserObject(self, username):
-        api_url = "https://m.tiktok.com/api/user/detail/?uniqueId={}&language=en&verifyFp=".format(
-            username)
+    def getUserObject(self, username, language='en'):
+        api_url = "https://m.tiktok.com/api/user/detail/?uniqueId={}&language={}&verifyFp=".format(
+            username, language)
         b = browser(api_url)
         return self.getData(api_url, b.signature, b.userAgent)['userInfo']['user']
 
